@@ -229,7 +229,7 @@ class BuildEnvironment:
             num: (int, list, tuple, np.ndarray) = 1,
             # items (stock if node is depot and demand if node is customer):
             max_items: (None, int, list, tuple, np.ndarray) = None,
-            init_items: (str, None, int, list, tuple, np.ndarray) = None,
+            init_items: (str, None, int, list, tuple, np.ndarray) = -1,
             item_rate: (None, int, list, tuple, np.ndarray) = None,
             item_recharge: (None, int, list, tuple, np.ndarray) = 0,
             init_items_at_step: (None, int, list, tuple, np.ndarray) = 0,
@@ -371,6 +371,12 @@ class BuildEnvironment:
             'action_rewards': action_rewards,
         }
 
+    def add_custom_obs(self, custom_obs):
+        self.obs_params = custom_obs
+
+    def add_custom_acts(self, custom_acts):
+        self.act_params = custom_acts
+
     def compile(
             self,
             TempDatabase: BaseTempDatabase = BaseTempDatabase,
@@ -441,8 +447,15 @@ class BuildEnvironment:
         self.visualizor = Visualizer(self.name, self.visual_params, self.temp_db)
 
         # Init observation and actions encoding/decoding:
-        self.obs_encoder = ObsEncoder(self.obs_params, self.temp_db, self.visualizor)
-        self.act_decoder = ActDecoder(self.act_params, self.temp_db, self.simulation)
+        if isinstance(self.obs_params, dict):
+            self.obs_encoder = ObsEncoder(self.obs_params, self.temp_db, self.visualizor)
+        else:
+            self.obs_encoder = self.obs_params(self.temp_db)
+
+        if isinstance(self.act_params, dict):
+            self.act_decoder = ActDecoder(self.act_params, self.temp_db, self.simulation)
+        else:
+            self.act_decoder = self.act_params(self.temp_db, self.simulation)
 
         # Init reward calculations:
         self.reward_calc = RewardCalculator(self.reward_params, self.temp_db)
