@@ -160,6 +160,7 @@ class BaseVehicleClass:
         self.cargo_type = v_params['cargo_type']
         self.v_loadable = v_params['loadable']
         self.v_weight = param_interpret(v_params['weight'])
+        self.speed = v_params['speed']
 
         self.temp_db.min_max_dict['v_weight'] = np.append(self.temp_db.min_max_dict['v_weight'], v_params['weight'])
 
@@ -208,7 +209,7 @@ class BaseVehicleClass:
         elif v_params['travel_type'] == 'arial':
             self.calc_distance = arial_distance
         else:
-            raise Exception("travel_type was set to '{}', but has to be: 'street', 'arial'".format(v_params['travel_type']))        
+            raise Exception("travel_type was set to '{}', but has to be: 'street', 'arial'".format(v_params['travel_type']))
 
 
     def take_action(self, calc_time=False):
@@ -216,6 +217,8 @@ class BaseVehicleClass:
         if len(self.temp_db.actions_list[self.v_index]) > 0:
             
             action_pack = self.temp_db.actions_list[self.v_index][0]
+            #print('actions', action_pack)
+
             
             if action_pack[0] == 'move':
                 self.v_move(calc_time=calc_time)
@@ -231,6 +234,42 @@ class BaseVehicleClass:
         else:
             self.temp_db.time_till_fin[self.v_index] = None
 
+    def set_node_as_destination(self, node_idx):
+        coordinates = np.array(self.temp_db.get_val('n_coord')[node_idx])
+        self.temp_db.status_dict['v_dest'][self.v_index] = coordinates
+
+    def calc_move_time(self, round_to=3, check_if_dest_reachable=True):
+
+        if bool(self.temp_db.status_dict['v_stuck'][self.v_index]):
+            return np.nan, True
+
+        direction = self.temp_db.status_dict['v_dest'][self.v_index] - self.temp_db.status_dict['v_coord'][self.v_index]
+        distance = self.calc_distance(direction)
+
+        if np.round(np.array([distance]), round_to) == 0:
+            return 0.0, False
+
+        time_frame = np.nanmax(self.range_restr.calc_time(distance), 0)
+
+        if check_if_dest_reachable:
+            self.range_restr.in_time(time_frame)
+            real_distance = self.range_restr.check_subtract_value(distance)
+
+            if np.round(np.array([distance]), round_to) != np.round(np.array([real_distance]), round_to):
+                return np.nan, True
+
+        return time_frame, False
+
+    def set_current_coord_to_dest(self):
+        coordinates = np.copy(
+            self.temp_db.status_dict['v_dest'][self.v_index]
+        )
+        self.temp_db.status_dict['v_coord'][self.v_index] = coordinates
+
+        if self.is_truck:
+            self.temp_db.past_coord_not_transportable_v[self.v_index].append(coordinates)
+        else:
+            self.temp_db.past_coord_transportable_v[0].append(coordinates)
 
     def v_move(self, calc_time=False):
 
@@ -239,13 +278,13 @@ class BaseVehicleClass:
 
         if np.round(np.array([distance]), 3) == 0:
             self.temp_db.status_dict['v_coord'][self.v_index] = self.temp_db.status_dict['v_dest'][self.v_index]
-            self.temp_db.actions_list[self.v_index].pop(0)
-            self.take_action(calc_time=True)
+            # self.temp_db.actions_list[self.v_index].pop(0)
+            # self.take_action(calc_time=True)
             return
 
         if bool(self.temp_db.status_dict['v_stuck'][self.v_index]):
-            self.temp_db.actions_list[self.v_index].pop(0)
-            self.take_action(calc_time=True)
+            # self.temp_db.actions_list[self.v_index].pop(0)
+            # self.take_action(calc_time=True)
             return
 
         if not calc_time:
@@ -257,13 +296,20 @@ class BaseVehicleClass:
                 self.temp_db.status_dict['v_coord'][self.v_index] = (
                     direction * (real_distance/distance) + self.temp_db.status_dict['v_coord'][self.v_index]
                 )
+                if self.is_truck:
+                    self.temp_db.past_coord_not_transportable_v[self.v_index].append(np.copy(self.temp_db.status_dict['v_coord'][self.v_index]))
+                else:
+                    self.temp_db.past_coord_transportable_v[self.v_index].append(np.copy(self.temp_db.status_dict['v_coord'][self.v_index]))
+
                 
                 for i in self.temp_db.v_transporting_v[self.v_index]:
                     self.temp_db.status_dict['v_coord'][i] = self.temp_db.status_dict['v_coord'][self.v_index]
+                    self.temp_db.past_coord_transportable_v[i].append(np.copy(
+                        self.temp_db.status_dict['v_coord'][self.v_index]))
 
             if np.round(real_distance - distance, 3) == 0:
-                self.temp_db.actions_list[self.v_index].pop(0)
-                self.take_action(calc_time=True)
+                # self.temp_db.actions_list[self.v_index].pop(0)
+                # self.take_action(calc_time=True)
                 return
 
             elif self.temp_db.cur_time_frame != 0:
@@ -460,8 +506,8 @@ class BaseVehicleClass:
         if item_amount == 0:
             self.temp_db.status_dict['n_waiting'][n_j] = 0
             
-            self.temp_db.actions_list[self.v_index].pop(0)
-            self.take_action(calc_time=True)
+            # self.temp_db.actions_list[self.v_index].pop(0)
+            # self.take_action(calc_time=True)
             return
 
         if not calc_time:
